/* This file is generated, all changes will be lost */
#ifndef __GSD_MARSHAL_MARSHAL_H__
#define __GSD_MARSHAL_MARSHAL_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* VOID:STRING,STRING (gsd-marshal.list:1) */
G_GNUC_INTERNAL
void gsd_marshal_VOID__STRING_STRING (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
                                      const GValue *param_values,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);


G_END_DECLS

#endif /* __GSD_MARSHAL_MARSHAL_H__ */
